#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-textual
version:              0.2.1.0
visibility:           public
id:                   blaze-textual-0.2.1.0-EzMzFABCTYfhzkEUae2hh
key:                  blaze-textual-0.2.1.0-EzMzFABCTYfhzkEUae2hh
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/bos/blaze-textual
synopsis:             Fast rendering of common datatypes
description:
    A library for efficiently rendering Haskell datatypes to
    bytestrings.

    /Note/: if you use GHCi or Template Haskell, please see the
    @README@ file for important details about building this package,
    and other packages that depend on it:
    <https://github.com/bos/blaze-textual#readme>

category:             Text
abi:                  63c136e7a24bee934749852ed2a458e0
exposed:              True
exposed-modules:      Blaze.Text Blaze.Text.Double Blaze.Text.Int
hidden-modules:       Blaze.Text.Double.Native
import-dirs:          /usr/lib/ghc-8.10.5/site-local/blaze-textual-0.2.1.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/blaze-textual-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/blaze-textual-0.2.1.0
hs-libraries:         HSblaze-textual-0.2.1.0-EzMzFABCTYfhzkEUae2hh
depends:
    base-4.14.2.0 blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB
    bytestring-0.10.12.0 ghc-prim-0.6.1 integer-gmp-1.0.3.0
    old-locale-1.0.0.7-L6Wsx5CTYHFJNpULKIS1yv text-1.2.4.1 time-1.9.3
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:
    /usr/share/doc/haskell-blaze-textual/html/blaze-textual.haddock

haddock-html:         /usr/share/doc/haskell-blaze-textual/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

